@@ -1,3 +1,6 @@
+#ifndef TP_GEN_TP_CLI_CONNECTION_H_INCLUDED
+#define TP_GEN_TP_CLI_CONNECTION_H_INCLUDED
+
 G_BEGIN_DECLS
 
 typedef void (*tp_cli_connection_signal_callback_self_handle_changed) (TpConnection *proxy,
@@ -1435,6 +1438,22 @@ gboolean tp_cli_connection_interface_contacts_run_get_contact_attributes (TpConn
 #endif /* not TP_DISABLE_DEPRECATED */
 
 
+typedef void (*tp_cli_connection_interface_contacts_callback_for_get_contact_by_id) (TpConnection *proxy,
+    guint out_Handle,
+    GHashTable *out_Attributes,
+    const GError *error, gpointer user_data,
+    GObject *weak_object);
+
+TpProxyPendingCall *tp_cli_connection_interface_contacts_call_get_contact_by_id (TpConnection *proxy,
+    gint timeout_ms,
+    const gchar *in_Identifier,
+    const gchar **in_Interfaces,
+    tp_cli_connection_interface_contacts_callback_for_get_contact_by_id callback,
+    gpointer user_data,
+    GDestroyNotify destroy,
+    GObject *weak_object);
+
+
 typedef void (*tp_cli_connection_interface_location_signal_callback_location_updated) (TpConnection *proxy,
     guint arg_Contact,
     GHashTable *arg_Location,
@@ -1931,3 +1950,5 @@ gboolean tp_cli_connection_interface_simple_presence_run_get_presences (TpConnec
 
 
 G_END_DECLS
+
+#endif /* defined (TP_GEN_TP_CLI_CONNECTION_H_INCLUDED) */
