@@ -1,7 +1,9 @@
 #include <glib-object.h>
 #include <dbus/dbus-glib.h>
+#include <telepathy-glib/dbus.h>
 #include <telepathy-glib/dbus-properties-mixin.h>
 
+
 G_BEGIN_DECLS
 
 typedef struct _TpSvcConnection TpSvcConnection;
@@ -1126,6 +1128,26 @@ tp_svc_connection_interface_contacts_return_from_get_contact_attributes (DBusGMe
       out_Attributes);
 }
 
+typedef void (*tp_svc_connection_interface_contacts_get_contact_by_id_impl) (TpSvcConnectionInterfaceContacts *self,
+    const gchar *in_Identifier,
+    const gchar **in_Interfaces,
+    DBusGMethodInvocation *context);
+void tp_svc_connection_interface_contacts_implement_get_contact_by_id (TpSvcConnectionInterfaceContactsClass *klass, tp_svc_connection_interface_contacts_get_contact_by_id_impl impl);
+static inline
+/* this comment is to stop gtkdoc realising this is static */
+void tp_svc_connection_interface_contacts_return_from_get_contact_by_id (DBusGMethodInvocation *context,
+    guint out_Handle,
+    GHashTable *out_Attributes);
+static inline void
+tp_svc_connection_interface_contacts_return_from_get_contact_by_id (DBusGMethodInvocation *context,
+    guint out_Handle,
+    GHashTable *out_Attributes)
+{
+  dbus_g_method_return (context,
+      out_Handle,
+      out_Attributes);
+}
+
 
 typedef struct _TpSvcConnectionInterfaceLocation TpSvcConnectionInterfaceLocation;
 
